multiformats.multibase
======================

.. automodule:: multiformats.multibase

Multibase
---------

.. autoclass:: multiformats.multibase.Multibase
    :members:

decode
------

.. autofunction:: multiformats.multibase.decode

decode_raw
----------

.. autofunction:: multiformats.multibase.decode_raw

encode
------

.. autofunction:: multiformats.multibase.encode

exists
------

.. autofunction:: multiformats.multibase.exists

from_str
--------

.. autofunction:: multiformats.multibase.from_str

get
---

.. autofunction:: multiformats.multibase.get

register
--------

.. autofunction:: multiformats.multibase.register

table
-----

.. autofunction:: multiformats.multibase.table

unregister
----------

.. autofunction:: multiformats.multibase.unregister

validate_multibase
------------------

.. autofunction:: multiformats.multibase.validate_multibase
